@@ -17,7 +17,7 @@ from instagrapi.exceptions import (BadPassword, ChallengeRequired,
                                    LoginRequired, PleaseWaitFewMinutes,
                                    RateLimitError, SentryBlock, UnknownError,
                                    VideoTooLongException)
-from instagrapi.utils import generate_signature, dumps
+from instagrapi.utils import dumps, generate_signature
 
 
 def manual_input_code(self, username: str, choice=None):
@@ -308,5 +308,4 @@ class PrivateRequestMixin:
                 # After challenge resolve return last_json
                 return self.last_json
             return self._send_private_request(endpoint, **kwargs)
-
         return self.last_json
